<template>
  <div>
    <el-bus-crud ref="crud" v-bind="tableConfig"></el-bus-crud>
    <el-dialog title="注册手机号修改" :visible.sync="dialogVisible" append-to-body :close-on-click-modal="false"
      class="form-content">
      <el-form key="sms" ref="smsForm" size="medium" :model="smsForm" :rules="smsRules">
        <el-form-item prop="username">
          <div class="input-wrapper">
            <el-input v-model="smsForm.username" placeholder="请输入手机号"></el-input>
          </div>
        </el-form-item>
        <el-form-item prop="smsCode">
          <div class="input-wrapper">
            <el-input v-model="smsForm.smsCode" placeholder="请输入短信验证码">
            </el-input>
            <el-bus-countdown-button send-type="login" :extra-body="{ userType: 'admin' }" :number="smsForm.username"
              type="text" class="sms-button"></el-bus-countdown-button>
          </div>
        </el-form-item>
        <el-form-item prop="code">
          <div class="input-wrapper">
            <el-input v-model="smsForm.code" placeholder="请输入图形验证码">
            </el-input>
            <img v-if="smsCaptchaCodeImageSrc" :src="smsCaptchaCodeImageSrc" alt="图形验证码"
              class="cursor-pointer w-auto h-45 object-contain" @click="getSmsCapacha" />
          </div>
        </el-form-item>
      </el-form>
      <div slot="footer" class="flex items-center justify-between">
        <div>
          <el-button @click="onCancel">取消</el-button>
          <el-button type="primary" @click="onConfirm">确定</el-button>
        </div>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { getAuditForm } from '@/utils/form-item-config'
export default {
  data() {
    return {
      dialogVisible: false,
      smsForm: {},
      smsCaptchaCodeImageSrc: "",
      smsRules: {
        username: { required: true, message: '请输入手机号', trigger: 'blur' },
        smsCode: {
          required: true,
          message: '请输入短信验证码',
          trigger: 'blur',
        },
        code: { required: true, message: '请输入图形验证码', trigger: 'blur' },
      },
      tableConfig: {
        url: 'flower/api/partner/page',
        hasNew: false,
        hasDelete: false,
        editUrl: 'flower/api/partner/page/change/area',
        beforeOpen: (row, isNew) => {
          if (!isNew) {
            const district = this.getDistrict(row)
            row.district = district
            row.districtStr = district
          }
        },
        operationAttrs: {
          width: '200px',
          fixed: 'right',
        },
        columns: [
          {
            label: 'ID',
            prop: 'id',
            minWidth: 60,
            fixed: 'left',
          },
          {
            label: '注册手机号',
            prop: 'loginName',
            minWidth: 150,
            fixed: 'left',
          },
          { label: '合伙人名称', prop: 'name', minWidth: 120, fixed: 'left' },
          {
            label: '服务地区',
            formatter: (row) => this.getDistrict(row),
            minWidth: 200,
          },
          {
            label: '联系方式',
            prop: 'contactTel',
            minWidth: 150,
          },
          { label: '注册时间', prop: 'createTime', minWidth: '180px' },
          {
            label: '审核时间',
            prop: 'passTime',
            minWidth: 180,
          },
          {
            label: '状态',
            prop: 'statusStr',
            minWidth: 150,
          },
          {
            label: '启用/禁用',
            formatter: (row) => (
              <el-switch
                value={row.isEnabled}
                onChange={this.onEnabledChange.bind(this, row)}
              ></el-switch>
            ),
            minWidth: 120,
            fixed: 'right',
          },
        ],
        searchForm: [
          {
            type: 'row',
            items: [
              {
                label: '注册手机号',
                id: 'loginName',
                type: 'input',
              },

              {
                label: '合伙人名称',
                id: 'name',
                type: 'input',
              },

              {
                label: '手机号',
                id: 'tel',
                type: 'input',
              },
              {
                label: '申请日期',
                component: 'el-bus-date-range',
                id: 'createDateBeginStr',
                commonFormat: true,
                commonFormatProps: ['createDateBeginStr', 'createDateEndStr'],
                customClass: 'in-bus-form',
              },
              {
                label: '服务地区',
                id: 'province',
                component: 'el-bus-select-area',
                el: {
                  clearable: true,
                },
                commonFormat: true,
                commonFormatProps: ['province', 'city', 'region'],
                customClass: 'in-bus-form',
              },
              {
                label: '状态',
                id: 'status',
                type: 'bus-select-dict',
                el: {
                  code: 'supplier_status',
                  clearable: true,
                  style: 'width:100%',
                },
              },
              {
                label: '启用/禁用',
                id: 'isEnabled',
                type: 'bus-select-dict',
                default: '1',
                el: {
                  code: 'USER_ENABLED_OR_DISABLED',
                  clearable: true,
                  style: 'width:100%',
                },
              },
            ],
          },
        ],
        form: [
          { label: '合伙人名称：', id: 'name', type: 'input',
            rules: { required: true, message: '请输入合伙人名称：' },
           },
           {
            label: '联系方式：',id: 'contactTel',type: 'input',
            rules: [{ required: true, message: '请输入有效的联系方式' ,pattern: /^1[3-9]\d{9}$/},
            ],
          },
          { label: '城市仓名称', id: 'cityWarehouse', type: 'input' ,
            rules: { required: true, message: '请输入城市仓名称' },
          },
          {
            label: '服务地区：',
            id: 'district',
            type: 'bus-cascader',
            el: {
              otherInterfaceUri: 'flower/api/pub/china/web/area/json',
              props: {
                label: 'name',
                value: 'code',
                multiple: true,
              },
              filterOptions: (list) => {
                if (typeof list === 'string') {
                  return JSON.parse(list)
                }
                return list
              },
              style: 'width:100%',
            },
            inputFormat: (row) => {
              if ('province' in row) {
                return row.province
                  ? row.province
                    .split(',')
                    .map((item, index) => [
                      item,
                      row.city.split(',')[index],
                      row.region.split(',')[index],
                    ])
                  : []
              }
            },
            outputFormat: (val) => {
              return Array.isArray(val) && val.length > 0
                ? {
                  province: val.map((item) => item[0]).join(','),
                  city: val.map((item) => item[1]).join(','),
                  region: val.map((item) => item[2]).join(','),
                }
                : { province: '', city: '', region: '' }
            },
            str: true,
            rules: { required: true, message: '请选择服务地区' },
          },
          { label: '地址', id: 'address', type: 'input' ,
            rules: { required: true, message: '请输入地址' },
          },
          {
            label: '身份证正反面：',
            id: 'idCards',
            component: 'el-bus-upload',
            el: {
              listType: 'picture-card',
            },
            commonFormat: true,
            forceDisabled: true,
            readonly: false,
            rules:[
            { required: true, message: '请上传身份证正反面' },
            {
              validator: (rule, value, callback) => {
                if (!value || value.length < 2) {
                  callback(new Error('请至少上传两张图片'));
                } else {
                  callback();
                }
              },
              trigger: 'change',
            },
            ],
          },
          {
            label: '状态：',
            id: 'status',
            type: 'input',
            str: true,
            readonly: true,
            hidden: (row, item, mode) => mode !== 'view',
          },
          {
            label: '不通过原因：',
            id: 'rejectReason',
            type: 'input',
            el: {
              type: 'textarea',
            },
            readonly: true,
            hidden: (row, item, mode) => mode !== 'view' || row.status !== 'R',
          },
        ],
        extraButtons: [
          {
            text: '审核',
            show: (row) => row.status === 'U',
            atClick: (row) => {
              const district = this.getDistrict(row)
              row.district = district
              row.districtStr = district
              this.$refs.crud.$refs.extraDialog[0].show(row)
              return false
            },
          },
          {
            text: '下载小程序码',
            show: (row) => row.status === 'P',
            atClick: async (row) => {
              if (row.wechatUrl) {
                window.open(row.wechatUrl, '_blank')
              } else {
                const { code, data } = await this.$elBusHttp.request(
                  'flower/api/partner/page/upload/code',
                  {
                    method: 'post',
                    data: {
                      id: row.id,
                    },
                  }
                )
                if (code === 0 && data) {
                  window.open(data, '_blank')
                }
              }
            },
          },
          {
            text: '注册手机号修改',
            atClick: (row) => {
              this.smsForm={}
              this.smsForm.id=row.id
              this.getSmsCapacha()
              this.dialogVisible = true
              return false
            },
          },
        ],
        extraDialogs: [
          {
            title: '审核',
            readonly: true,
            form: getAuditForm(),
            atConfirm: async (val) => {
              const { code } = await this.$elBusHttp.request(
                'flower/api/partner/page/audit',
                {
                  method: 'post',
                  data: {
                    ...val,
                    rejectReason: val.auditRejectReason,
                  },
                }
              )
              if (code === 0) {
                this.$message.success('操作成功')
              }
            },
          },

        ],
      },
    }
  },
  head() {
    return {
      title: '合伙人列表',
    }
  },
  methods: {
    onCancel() {
      this.$refs.smsForm.resetFields(); // 重置表单
      this.dialogVisible = false
    },
    async onConfirm() {
      const param=this.smsForm
      const { code, data } = await this.$elBusHttp.request(
        'flower/api/partner/phone/update',
        {
          method: 'post',
          data:param,
        }
      )
      if (code === 0) {
        this.$message.success(`更新成功`)
        this.$refs.crud.getList()
        this.onCancel()
      }
    },
    async getSmsCapacha() {
      const { captchaCodeId, imageSrc } =
        await this.$services.base.createCaptcha()
      this.smsForm.codeId = captchaCodeId
      this.smsCaptchaCodeImageSrc = imageSrc
    },
    getDistrict(row) {
      if (row.province) {
        return row.province
          .split(',')
          .map((item, index) =>
            [
              item,
              row.city.split(',')[index],
              row.region.split(',')[index],
            ].join('-')
          )
          .join(',')
      }
      return ''
    },
    onEnabledChange(row, e) {
      const url = 'flower/api/partner/page/isEnable'
      const text = e ? '启用' : '禁用'
      this.$elBusUtil
        .confirm(`确定要${text}这个合伙人吗？`)
        .then(async () => {
          const { code } = await this.$elBusHttp.request(url, {
            params: {
              id: row.id,
            },
          })
          if (code === 0) {
            this.$message.success(`${text}成功`)
            this.$refs.crud.getList()
          }
        })
        .catch(() => { })
    },
  },
}
</script>

<style lang="scss" scoped>
.input-wrapper {
  display: flex;
  align-items: center;

  // border-bottom: 1px solid #cecece;
  &:hover {
    border-color: $primary-color;
  }
}
</style>
